/// Copyright Thomas Nagy 2007
/// License: QPL

#ifndef izlthb
#define izlthb

#include <QGraphicsRectItem>
#include <QRectF>
#include "con.h"

class dbz;
class rsltb;
class izltb : public QGraphicsRectItem
<%
	public:
		izltb(dbz*);
		~izltb();

		int type() const <% return gratype(39); %>

		void paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *);
		bool kitzjl;

		int elodez;
		int alkt;
		int zandek;
		int fladat;

		int eler;
		QPointF kket;

		rsltb *vmrgem;
		rsltb *targy;

		dbz *kelt;

		void jlnrdz();

		void nybnvn(QPainter *adelk, int fnqll, QPointF hsztzk);

		bool contains(const QPointF& hsztzk) CONST;

		int jlzpnt;

		QList<QPoint> vnl;
		QList<QPoint> kidlgz;
		QList<QPoint> lnmtat; 

		void akdaly();

		static int hzzqjt(const QRectF&, const QPointF&);
		int tqrost(const QRectF&, int, const QPointF&);
%>;

#endif 

